// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PLASMAACTIVITIESSTATS_VERSION_H
#define PLASMAACTIVITIESSTATS_VERSION_H

#define PLASMAACTIVITIESSTATS_VERSION_STRING "6.6.2"
#define PLASMAACTIVITIESSTATS_VERSION_MAJOR 6
#define PLASMAACTIVITIESSTATS_VERSION_MINOR 6
#define PLASMAACTIVITIESSTATS_VERSION_PATCH 2
#define PLASMAACTIVITIESSTATS_VERSION ((6<<16)|(6<<8)|(2))

#endif
